summaryrefslogtreecommitdiff
path: root/src/components/policy/policy_regular/include/policy/policy_manager_impl.h
diff options
context:
space:
mode:
authorjacobkeeler <jacob.keeler@livioradio.com>2019-03-06 13:20:21 -0500
committerjacobkeeler <jacob.keeler@livioradio.com>2019-03-06 13:20:21 -0500
commitbcd314658814edf6b822b9a23267c0694865e06c (patch)
tree19a41eced6de792941d1d0ef6064ed9e243c6bd2 /src/components/policy/policy_regular/include/policy/policy_manager_impl.h
parent7b2af762ed58252c2d01a6a3bc1dc4a8ec13f5da (diff)
downloadsdl_core-bcd314658814edf6b822b9a23267c0694865e06c.tar.gz
Implement cloud app properties revisionfeature/cloud_app_properties_revisions
Diffstat (limited to 'src/components/policy/policy_regular/include/policy/policy_manager_impl.h')
-rw-r--r--src/components/policy/policy_regular/include/policy/policy_manager_impl.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/components/policy/policy_regular/include/policy/policy_manager_impl.h b/src/components/policy/policy_regular/include/policy/policy_manager_impl.h
index 5e46ff9fa1..1b5a78ed00 100644
--- a/src/components/policy/policy_regular/include/policy/policy_manager_impl.h
+++ b/src/components/policy/policy_regular/include/policy/policy_manager_impl.h
@@ -642,11 +642,11 @@ class PolicyManagerImpl : public PolicyManager {
const std::string& endpoint) OVERRIDE;
/**
* @brief Set a cloud app's name
* @param app_name Nickname for cloud app
*/
- void SetAppName(const std::string& policy_app_id,
- const std::string& app_name) OVERRIDE;
+ void SetAppNicknames(const std::string& policy_app_id,
+ const StringArray& nicknames) OVERRIDE;
/**
* @brief Set the user preference for how a hybrid (cloud and mobile) app
@@ -642,11 +642,11 @@ class PolicyManagerImpl : public PolicyManager {
const std::string& endpoint) OVERRIDE;
/**
- * @brief Set a cloud app's name
- * @param app_name Nickname for cloud app
+ * @brief Set a cloud app's nicknames
+ * @param nicknames Nicknames for cloud app
*/